Method: Polars::DataType.float?
- Defined in:
- lib/polars/data_types.rb
.float? ⇒ Boolean
Check whether the data type is a float type.
84 85 86 |
# File 'lib/polars/data_types.rb', line 84 def self.float? self < FloatType end |
Check whether the data type is a float type.
84 85 86 |
# File 'lib/polars/data_types.rb', line 84 def self.float? self < FloatType end |