Method: Polars::DataType.nested?
- Defined in:
- lib/polars/data_types.rb
.nested? ⇒ Boolean
Check whether the data type is a nested type.
98 99 100 |
# File 'lib/polars/data_types.rb', line 98 def self.nested? self < NestedType end |
Check whether the data type is a nested type.
98 99 100 |
# File 'lib/polars/data_types.rb', line 98 def self.nested? self < NestedType end |