Method: Polars::Expr#is_null
- Defined in:
- lib/polars/expr.rb
#is_null ⇒ Expr
Returns a boolean Series indicating which values are null.
556 557 558 |
# File 'lib/polars/expr.rb', line 556 def is_null wrap_expr(_rbexpr.is_null) end |
Returns a boolean Series indicating which values are null.
556 557 558 |
# File 'lib/polars/expr.rb', line 556 def is_null wrap_expr(_rbexpr.is_null) end |