Method: Polars::Expr#struct
- Defined in:
- lib/polars/expr.rb
#struct ⇒ StructExpr
Create an object namespace of all struct related methods.
8336 8337 8338 |
# File 'lib/polars/expr.rb', line 8336 def struct StructExpr.new(self) end |
Create an object namespace of all struct related methods.
8336 8337 8338 |
# File 'lib/polars/expr.rb', line 8336 def struct StructExpr.new(self) end |