Method: Polars::Testing#assert_series_equal

Defined in:
lib/polars/testing.rb

#assert_series_equal(left, right, check_dtype: true, check_names: true, check_order: true, check_exact: false, rtol: 1e-5, atol: 1e-8, categorical_as_str: false) ⇒ nil

Assert that the left and right Series are equal.

Raises a detailed AssertionError if the Series differ. This function is intended for use in unit tests.

Parameters:

  • left (Object)

    The first Series to compare.

  • right (Object)

    The second Series to compare.

  • check_dtype (Boolean) (defaults to: true)

    Require data types to match.

  • check_names (Boolean) (defaults to: true)

    Require names to match.

  • check_order (Boolean) (defaults to: true)

    Requires elements to appear in the same order.

  • check_exact (Boolean) (defaults to: false)

    Require float values to match exactly. If set to false, values are considered equal when within tolerance of each other (see rtol and atol). Only affects columns with a Float data type.

  • rtol (Float) (defaults to: 1e-5)

    Relative tolerance for inexact checking, given as a fraction of the values in right.

  • atol (Float) (defaults to: 1e-8)

    Absolute tolerance for inexact checking.

  • categorical_as_str (Boolean) (defaults to: false)

    Cast categorical columns to string before comparing. Enabling this helps compare columns that do not share the same string cache.

Returns:

  • (nil)


148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/polars/testing.rb', line 148

def assert_series_equal(
  left,
  right,
  check_dtype: true,
  check_names: true,
  check_order: true,
  check_exact: false,
  rtol: 1e-5,
  atol: 1e-8,
  categorical_as_str: false
)
  if !(left.is_a?(Series) && right.is_a?(Series))
    raise_assertion_error(
      "inputs",
      "unexpected input types",
      left.class.name,
      right.class.name
    )
  end

  Plr.assert_series_equal_rb(
    left._s,
    right._s,
    check_dtype,
    check_names,
    check_order,
    check_exact,
    rtol,
    atol,
    categorical_as_str
  )
end