Class: Polars::CatNameSpace
- Inherits:
-
Object
- Object
- Polars::CatNameSpace
- Defined in:
- lib/polars/cat_name_space.rb
Overview
Series.cat namespace.
Instance Method Summary collapse
-
#ends_with(suffix) ⇒ Series
Check if string representations of values end with a substring.
-
#get_categories ⇒ Series
Get the categories stored in this data type.
-
#is_local ⇒ Boolean
deprecated
Deprecated.
cat.is_localis deprecated; Categoricals no longer have a local scope. -
#len_bytes ⇒ Series
Return the byte-length of the string representation of each value.
-
#len_chars ⇒ Series
Return the number of characters of the string representation of each value.
-
#slice(offset, length = nil) ⇒ Series
Extract a substring from the string representation of each string value.
-
#starts_with(prefix) ⇒ Series
Check if string representations of values start with a substring.
-
#to_local ⇒ Series
Simply returns the column as-is, local representations are deprecated.
-
#uses_lexical_ordering ⇒ Boolean
deprecated
Deprecated.
cat.uses_lexical_orderingis deprecated; Categoricals are now always ordered lexically.
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Polars::ExprDispatch
Instance Method Details
#ends_with(suffix) ⇒ Series
Check if string representations of values end with a substring.
146 147 148 |
# File 'lib/polars/cat_name_space.rb', line 146 def ends_with(suffix) super end |
#get_categories ⇒ Series
Get the categories stored in this data type.
28 29 30 |
# File 'lib/polars/cat_name_space.rb', line 28 def get_categories super end |
#is_local ⇒ Boolean
cat.is_local is deprecated; Categoricals no longer have a local scope.
Return whether or not the column is a local categorical.
Always returns false.
40 41 42 |
# File 'lib/polars/cat_name_space.rb', line 40 def is_local _s.cat_is_local end |
#len_bytes ⇒ Series
Return the byte-length of the string representation of each value.
82 83 84 |
# File 'lib/polars/cat_name_space.rb', line 82 def len_bytes super end |
#len_chars ⇒ Series
Return the number of characters of the string representation of each value.
102 103 104 |
# File 'lib/polars/cat_name_space.rb', line 102 def len_chars super end |
#slice(offset, length = nil) ⇒ Series
Extract a substring from the string representation of each string value.
184 185 186 |
# File 'lib/polars/cat_name_space.rb', line 184 def slice(offset, length = nil) super end |
#starts_with(prefix) ⇒ Series
Check if string representations of values start with a substring.
124 125 126 |
# File 'lib/polars/cat_name_space.rb', line 124 def starts_with(prefix) super end |
#to_local ⇒ Series
Simply returns the column as-is, local representations are deprecated.
47 48 49 |
# File 'lib/polars/cat_name_space.rb', line 47 def to_local Utils.wrap_s(_s.cat_to_local) end |
#uses_lexical_ordering ⇒ Boolean
cat.uses_lexical_ordering is deprecated; Categoricals are now always ordered lexically.
Indicate whether the Series uses lexical ordering.
62 63 64 |
# File 'lib/polars/cat_name_space.rb', line 62 def uses_lexical_ordering _s.cat_uses_lexical_ordering end |