Class: Polars::ExtensionNameSpace

Inherits:
Object
  • Object
show all
Defined in:
lib/polars/extension_name_space.rb

Overview

Series.ext namespace.

Instance Method Summary collapse

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Polars::ExprDispatch

Instance Method Details

#storageSeries

Note:

This functionality is currently considered unstable. It may be changed at any point without it being considered a breaking change.

Get the storage values of a Series with an extension data type.

If the input series does not have an extension data type, it is returned as-is.

Returns:



35
36
37
# File 'lib/polars/extension_name_space.rb', line 35

def storage
  Utils.wrap_s(_s.ext_storage)
end

#to(dtype) ⇒ Series

Note:

This functionality is currently considered unstable. It may be changed at any point without it being considered a breaking change.

Create a Series with an extension dtype.

The input series must have the storage type of the extension dtype.

Returns:



22
23
24
# File 'lib/polars/extension_name_space.rb', line 22

def to(dtype)
  Utils.wrap_s(_s.ext_to(dtype))
end