Class: Polars::StringCache Deprecated

Inherits:
Object
  • Object
show all
Defined in:
lib/polars/string_cache.rb

Overview

Deprecated.

The string cache was used to maintain the mapping for the Categorical dtype, this is now done through Polars::Categories.

Does nothing.

Instance Method Summary collapse

Constructor Details

#initialize(&block) ⇒ StringCache

Returns a new instance of StringCache.



8
9
# File 'lib/polars/string_cache.rb', line 8

def initialize(&block)
end