Method: Polars::Expr#all
- Defined in:
- lib/polars/expr.rb
#all(ignore_nulls: true) ⇒ Boolean
Check if all boolean values in a Boolean column are true.
This method is an expression - not to be confused with
Polars.all which is a function to select all columns.
251 252 253 |
# File 'lib/polars/expr.rb', line 251 def all(ignore_nulls: true) wrap_expr(_rbexpr.all(ignore_nulls)) end |