Method: Polars::Expr#rolling_std_by
- Defined in:
- lib/polars/expr.rb
#rolling_std_by(by, window_size, min_samples: 1, closed: "right", ddof: 1) ⇒ Expr
Note:
If you want to compute multiple aggregation statistics over the same dynamic
window, consider using rolling - this method can cache the window size
computation.
Compute a rolling standard deviation based on another column.
5239 5240 5241 5242 5243 5244 5245 5246 5247 5248 5249 5250 5251 5252 5253 5254 5255 5256 5257 |
# File 'lib/polars/expr.rb', line 5239 def rolling_std_by( by, window_size, min_samples: 1, closed: "right", ddof: 1 ) window_size = _prepare_rolling_by_window_args(window_size) by = Utils.parse_into_expression(by) wrap_expr( _rbexpr.rolling_std_by( by, window_size, min_samples, closed, ddof ) ) end |