Method: Polars::Functions#all
- Defined in:
- lib/polars/functions/aggregation/vertical.rb
#all(*names, ignore_nulls: true) ⇒ Expr
Either return an expression representing all columns, or evaluate a bitwise AND operation.
If no arguments are passed, this function is syntactic sugar for col("*").
Otherwise, this function is syntactic sugar for col(names).all.
44 45 46 47 48 49 50 |
# File 'lib/polars/functions/aggregation/vertical.rb', line 44 def all(*names, ignore_nulls: true) if names.empty? return col("*") end col(*names).all(ignore_nulls: ignore_nulls) end |