Method: Polars::Functions#enable_string_cache
- Defined in:
- lib/polars/string_cache.rb
#enable_string_cache ⇒ nil
Enable the global string cache.
Categorical columns created under the same global string cache have
the same underlying physical value when string values are equal. This allows the
columns to be concatenated or used in a join operation, for example.
63 64 65 |
# File 'lib/polars/string_cache.rb', line 63 def enable_string_cache Plr.enable_string_cache end |