Method: Polars::NameExpr#keep
- Defined in:
- lib/polars/name_expr.rb
#keep ⇒ Expr
Note:
Due to implementation constraints, this method can only be called as the last expression in a chain.
Keep the original root name of the expression.
51 52 53 |
# File 'lib/polars/name_expr.rb', line 51 def keep Utils.wrap_expr(_rbexpr.name_keep) end |