Method: Polars::StringExpr#len_bytes
- Defined in:
- lib/polars/string_expr.rb
#len_bytes ⇒ Expr
Note:
The returned lengths are equal to the number of bytes in the UTF8 string. If you
need the length in terms of the number of characters, use n_chars instead.
Get length of the strings as :u32 (as number of bytes).
311 312 313 |
# File 'lib/polars/string_expr.rb', line 311 def len_bytes Utils.wrap_expr(_rbexpr.str_len_bytes) end |