Method: Polars::Testing#assert_series_not_equal
- Defined in:
- lib/polars/testing.rb
#assert_series_not_equal(left, right, check_dtype: true, check_names: true, check_exact: false, rtol: 1e-5, atol: 1e-8, categorical_as_str: false) ⇒ nil
Assert that the left and right Series are not equal.
This function is intended for use in unit tests.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/polars/testing.rb', line 207 def assert_series_not_equal( left, right, check_dtype: true, check_names: true, check_exact: false, rtol: 1e-5, atol: 1e-8, categorical_as_str: false ) begin assert_series_equal( left, right, check_dtype: check_dtype, check_names: check_names, check_exact: check_exact, rtol: rtol, atol: atol, categorical_as_str: categorical_as_str ) rescue AssertionError return end msg = "Series are equal" raise AssertionError, msg end |